@@ -1,9 +1,9 @@
 // --
-// Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
+// Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
-// the enclosed file COPYING for license information (AGPL). If you
-// did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+// the enclosed file COPYING for license information (GPL). If you
+// did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 // --
 
 "use strict";
@@ -59,13 +59,18 @@ Core.Agent.Admin.GenericInterfaceDebugger = (function (TargetNS) {
      * @name Init
      * @memberof Core.Agent.Admin.GenericInterfaceDebugger
      * @function
-     * @param {Object} Params
      * @description
      *      Initializes the module functions.
      */
-    TargetNS.Init = function (Params) {
-        TargetNS.WebserviceID = parseInt(Params.WebserviceID, 10);
-        TargetNS.Localization = Params.Localization;
+    TargetNS.Init = function () {
+
+        TargetNS.WebserviceID = parseInt(Core.Config.Get('WebserviceID'), 10);
+
+        // add click binds
+        $('#FilterRefresh').on('click', TargetNS.GetRequestList);
+        $('#DeleteButton').on('click', TargetNS.ShowDeleteDialog);
+
+        TargetNS.GetRequestList();
     };
 
     /**
@@ -81,11 +86,11 @@ Core.Agent.Admin.GenericInterfaceDebugger = (function (TargetNS) {
             Subaction: 'GetRequestList',
             WebserviceID: TargetNS.WebserviceID,
             FilterLimit: $('#FilterLimit').val() || '',
+            FilterSort: $('#FilterSort').val() || '',
             FilterRemoteIP: $('#FilterRemoteIP').val() || '',
             FilterType: $('#FilterType').val() || ''
         };
 
-
         Data.FilterFrom = FormatISODate($('#FilterFromYear').val(), $('#FilterFromMonth').val(), $('#FilterFromDay').val()) + ' 00:00:00';
         Data.FilterTo = FormatISODate($('#FilterToYear').val(), $('#FilterToMonth').val(), $('#FilterToDay').val()) + ' 23:59:59';
 
@@ -96,14 +101,14 @@ Core.Agent.Admin.GenericInterfaceDebugger = (function (TargetNS) {
             var HTML = '';
 
             if (!Response || !Response.LogData) {
-                alert(TargetNS.Localization.CommunicationErrorMsg);
+                alert(Core.Language.Translate('An error occurred during communication.'));
                 return;
             }
 
             $('.RequestListWidget').removeClass('Loading');
 
             if (!Response.LogData.length) {
-                $('#RequestList tbody').empty().append('<tr><td colspan="3">' + TargetNS.Localization.NoDataFoundMsg + '</td></tr>');
+                $('#RequestList tbody').empty().append('<tr><td colspan="4">' + Core.Language.Translate('No data found.') + '</td></tr>');
                 return;
             }
 
@@ -113,15 +118,19 @@ Core.Agent.Admin.GenericInterfaceDebugger = (function (TargetNS) {
                 HTML += '<tr>';
                 HTML += '<td><a href="#" class="AsBlock">' + this.CommunicationType + '<input type="hidden" class="CommunicationID" value="' + this.CommunicationID + '" /></a></td>';
                 HTML += '<td><a href="#" class="AsBlock">' + this.Created + '</a></td>';
+                HTML += '<td><a href="#" class="AsBlock">' + this.CommunicationID + '</a></td>';
                 HTML += '<td><a href="#" class="AsBlock">' + (this.RemoteIP || '-') + '</a></td>';
                 HTML += '</tr>';
             });
 
             $('#RequestList tbody').html(HTML);
 
-            $('#RequestList a').bind('click', function() {
+            $('#RequestList a').on('click', function() {
                 var CommunicationID = $(this).blur().parents('tr').find('input.CommunicationID').val();
 
+                // highlight selected entry
+                $(this).parents('tr').addClass('Active').siblings().removeClass('Active');
+
                 TargetNS.LoadCommunicationDetails(CommunicationID);
 
                 return false;
@@ -152,24 +161,28 @@ Core.Agent.Admin.GenericInterfaceDebugger = (function (TargetNS) {
 
         Core.AJAX.FunctionCall(Core.Config.Get('CGIHandle'), Data, function (Response) {
             if (!Response || !Response.LogData || !Response.LogData.Data) {
-                alert(TargetNS.Localization.CommunicationErrorMsg);
+                alert(Core.Language.Translate('An error occurred during communication.'));
                 return;
             }
 
+            $('#CommunicationDetails > .Header').empty();
             $('#CommunicationDetails > .Content').empty();
             $('.RequestListWidget').removeClass('Loading');
 
             if (!Response.LogData.Data.length) {
-                $('#CommunicationDetails > .Content').append('<p class="ErrorMessage">' + TargetNS.Localization.NoDataFoundMsg + '</p>');
+                $('#CommunicationDetails > .Header').append('<h2>' + Core.Language.Translate('Request Details') + '</h2>');
+                $('#CommunicationDetails > .Content').append('<p class="ErrorMessage">' + Core.Language.Translate('No data found.') + '</p>');
                 $('#CommunicationDetails').css('visibility', 'visible').show();
             }
             else {
+                $('#CommunicationDetails > .Header').append('<h2>' + Core.Language.Translate('Request Details for Communication ID') + ' ' + CommunicationID + '</h2>');
+
                 $.each(Response.LogData.Data, function(){
                     var $Container = $('<div class="WidgetSimple Expanded"></div>'),
                         $Header = $('<div class="Header"></div>'),
                         $Content = $('<div class="Content"></div>');
 
-                    $Header.append('<div class="WidgetAction Toggle"><a href="#" title="' + TargetNS.Localization.ToggleContentMsg + '"><i class="fa fa-caret-right"></i><i class="fa fa-caret-down"></i></a></div>');
+                    $Header.append('<div class="WidgetAction Toggle"><a href="#" title="' + Core.Language.Translate('Show or hide the content.') + '"><i class="fa fa-caret-right"></i><i class="fa fa-caret-down"></i></a></div>');
                     $Header.append('<h3 class="DebugLevel_' + this.DebugLevel + '">' + this.Summary + ' (' + this.Created + ', ' + this.DebugLevel + ')</h3>');
                     $Container.append($Header);
 
@@ -203,19 +216,19 @@ Core.Agent.Admin.GenericInterfaceDebugger = (function (TargetNS) {
     TargetNS.ShowDeleteDialog = function(Event){
         Core.UI.Dialog.ShowContentDialog(
             $('#DeleteDialogContainer'),
-            TargetNS.Localization.ClearDebugLogMsg,
+            Core.Language.Translate('Clear debug log'),
             '240px',
             'Center',
             true,
             [
                {
-                   Label: TargetNS.Localization.CancelMsg,
+                   Label: Core.Language.Translate('Cancel'),
                    Function: function () {
                        Core.UI.Dialog.CloseDialog($('#DeleteDialog'));
                    }
                },
                {
-                   Label: TargetNS.Localization.ClearMsg,
+                   Label: Core.Language.Translate('Clear'),
                    Function: function () {
                        var Data = {
                             Action: 'AdminGenericInterfaceDebugger',
@@ -228,7 +241,7 @@ Core.Agent.Admin.GenericInterfaceDebugger = (function (TargetNS) {
 
                         Core.AJAX.FunctionCall(Core.Config.Get('CGIHandle'), Data, function (Response) {
                             if (!Response || !Response.Success) {
-                                alert(TargetNS.Localization.CommunicationErrorMsg);
+                                alert(Core.Language.Translate('An error occurred during communication.'));
                                 return;
                             }
 
@@ -245,5 +258,7 @@ Core.Agent.Admin.GenericInterfaceDebugger = (function (TargetNS) {
         Event.stopPropagation();
     };
 
+    Core.Init.RegisterNamespace(TargetNS, 'APP_MODULE');
+
     return TargetNS;
 }(Core.Agent.Admin.GenericInterfaceDebugger || {}));
