@@ -1,9 +1,9 @@
 // --
-// Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
+// Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
-// the enclosed file COPYING for license information (AGPL). If you
-// did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+// the enclosed file COPYING for license information (GPL). If you
+// did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 // --
 
 "use strict";
@@ -539,12 +539,26 @@ Core.UI = (function (TargetNS) {
                 NoSpaceLeft = [],
                 NoSpaceLeftText,
                 UsedSpace = 0,
-                WebMaxFileUpload = Core.Config.Get('WebMaxFileUpload');
+                WebMaxFileUpload = Core.Config.Get('WebMaxFileUpload'),
+                CGIHandle = Core.Config.Get('CGIHandle'),
+                SessionToken = '',
+                SessionName;
 
             if (!FormID || !SelectedFiles || !$DropObj || !ChallengeToken) {
                 return false;
             }
 
+            // If SessionUseCookie is disabled use Session cookie in AjaxAttachment. See bug#14432.
+            if (Core.Config.Get('SessionUseCookie') === '0') {
+                if (CGIHandle.indexOf('index') > -1) {
+                    SessionName =  Core.Config.Get('SessionName');
+                }
+                else if (CGIHandle.indexOf('customer') > -1) {
+                    SessionName =  Core.Config.Get('CustomerPanelSessionName');
+                }
+                SessionToken = ';' + SessionName + '=' + $DropObj.closest('form').find('input[name=' + SessionName + ']').val();
+            }
+
             // if the original upload field doesn't have the multiple attribute,
             // prevent uploading of more than one file
             if (!IsMultiple && SelectedFiles.length > 1) {
@@ -591,7 +605,8 @@ Core.UI = (function (TargetNS) {
                     AttachmentItem = Core.Template.Render('AjaxDnDUpload/AttachmentItemUploading', {
                         'Filename' : File.name,
                         'Filetype' : File.type
-                    });
+                    }),
+                    FileExist;
 
                 // check uploaded file size
                 if (File.size > (WebMaxFileUpload - UsedSpace)) {
@@ -615,7 +630,12 @@ Core.UI = (function (TargetNS) {
                 }
 
                 // don't allow uploading multiple files with the same name
-                if ($ContainerObj.find('.AttachmentList tbody tr td.Filename:contains(' + File.name + ')').length) {
+                FileExist = $ContainerObj.find('.AttachmentList tbody tr td.Filename').filter(function() {
+                    if ($(this).text() === File.name) {
+                        return $(this);
+                    }
+                });
+                if (FileExist.length) {
                     AttemptedToUploadAgain.push(File.name);
                     return true;
                 }
@@ -630,7 +650,7 @@ Core.UI = (function (TargetNS) {
                 Upload.append('Files', File);
 
                 $.ajax({
-                    url: Core.Config.Get('CGIHandle') + '?Action=AjaxAttachment;Subaction=Upload;FormID=' + FormID + ';ChallengeToken=' + ChallengeToken,
+                    url: Core.Config.Get('CGIHandle') + '?Action=AjaxAttachment;Subaction=Upload;FormID=' + FormID + ';ChallengeToken=' + ChallengeToken + SessionToken,
                     type: 'post',
                     data: Upload,
                     xhr: function() {
@@ -664,7 +684,11 @@ Core.UI = (function (TargetNS) {
 
                             // walk through the list to see if we can update an entry
                             var AttachmentItem,
-                                $ExistingItemObj = $ContainerObj.find('.AttachmentList tbody tr td.Filename:contains(' + Attachment.Filename + ')'),
+                                $ExistingItemObj = $ContainerObj.find('.AttachmentList tbody tr td.Filename').filter(function() {
+                                    if ($(this).text() === Attachment.Filename) {
+                                        return $(this);
+                                    }
+                                }),
                                 $TargetObj;
 
                             // update the existing item if one exists
@@ -769,12 +793,12 @@ Core.UI = (function (TargetNS) {
 
         $('.AttachmentList').each(function() {
             if ($(this).find('tbody tr').length) {
-                $('.AttachmentList').show();
+                $(this).show();
             }
         });
 
         // Attachment deletion
-        $('.AttachmentList').on('click', '.AttachmentDelete', function() {
+        $('.AttachmentList').off('click').on('click', '.AttachmentDelete', function() {
 
             var $TriggerObj = $(this),
                 $AttachmentListContainerObj = $TriggerObj.closest('.AttachmentListContainer'),
@@ -830,6 +854,11 @@ Core.UI = (function (TargetNS) {
                     'IsMultiple': IsMultiple
                 });
 
+            // Only initialize events once per attachment field.
+            if ($(this).next().hasClass('AjaxDnDUploadReady')) {
+                return;
+            }
+
             $(this)
                 .val('')
                 .hide()
@@ -838,11 +867,24 @@ Core.UI = (function (TargetNS) {
                 })
                 .after($(UploadContainer))
                 .next('.DnDUpload')
-                .on('click', function() {
+                .on('click keydown', function(Event) {
+
+                    if (Event.keyCode && Event.keyCode == 9) {
+                        return true;
+                    }
+
+                    // The file selection dialog should also appear on focusing the element and pressing enter/space.
+                    if (Event.keyCode && (Event.keyCode != 13 && Event.keyCode != 32)) {
+                        return false;
+                    }
+
+                    // If this certain upload field does not allow uploading more than one file and a file has
+                    // already been uploaded, prevent the user from uploading more files.
                     if (!IsMultiple && $(this).closest('.Field').find('.AttachmentList tbody tr').length > 0) {
                         alert(Core.Language.Translate("Sorry, you can only upload one file here."));
                         return false;
                     }
+
                     $(this).prev('input.AjaxDnDUpload').trigger('click');
                 })
                 .on('drag dragstart dragend dragover dragenter dragleave drop', function(Event) {
@@ -857,7 +899,8 @@ Core.UI = (function (TargetNS) {
                 })
                 .on('drop', function(Event) {
                     UploadFiles(Event.originalEvent.dataTransfer.files, $(this));
-                });
+                })
+                .addClass('AjaxDnDUploadReady');
         });
     };
 
